@@ -214,10 +214,13 @@ def error(msg, s, **kwargs):
     msg.tag('isError')
     return reply(msg, s, **kwargs)
 
-def getHelp(method, name=None):
+def getHelp(method, name=None, doc=None):
     if name is None:
         name = method.__name__
-    doclines = method.__doc__.splitlines()
+    if doc is None:
+        doclines = method.__doc__.splitlines()
+    else:
+        doclines = doc.splitlines()
     s = '%s %s' % (name, doclines.pop(0))
     if doclines:
         help = ' '.join(doclines)
@@ -1087,6 +1090,8 @@ class Commands(BasePlugin):
         # name = canonicalName(name)
         if self.isDisabled(name):
             return False
+        if name != canonicalName(name):
+            return False
         if hasattr(self, name):
             method = getattr(self, name)
             if inspect.ismethod(method):
