@@ -33,7 +33,7 @@ import socket
 import sgmllib
 import threading
 
-import rssparser
+import feedparser
 
 import supybot.conf as conf
 import supybot.utils as utils
@@ -139,7 +139,9 @@ class RSS(callbacks.Plugin):
         if self.registryValue(config, channel):
             for headline in headlines:
                 if headline[1]:
-                    newheadlines.append(format('%s %u', *headline))
+                    newheadlines.append(format('%s %u',
+                                               headline[0],
+                                               headline[1].encode('utf-8')))
                 else:
                     newheadlines.append(format('%s', headline[0]))
         else:
@@ -225,11 +227,11 @@ class RSS(callbacks.Plugin):
             if self.willGetNewFeed(url):
                 try:
                     self.log.debug('Downloading new feed from %u', url)
-                    results = rssparser.parse(url)
+                    results = feedparser.parse(url)
                     if 'bozo_exception' in results:
                         raise results['bozo_exception']
                 except sgmllib.SGMLParseError:
-                    self.log.exception('Uncaught exception from rssparser:')
+                    self.log.exception('Uncaught exception from feedparser:')
                     raise callbacks.Error, 'Invalid (unparsable) RSS feed.'
                 except socket.timeout:
                     return error('Timeout downloading feed.')
@@ -414,11 +416,11 @@ class RSS(callbacks.Plugin):
             when = 'time unavailable'
         title = conv(info.get('title', 'unavailable'))
         desc = conv(info.get('description', 'unavailable'))
+        link = conv(info.get('link', 'unavailable'))
         # The rest of the entries are all available in the channel key
         response = format('Title: %s;  URL: %u;  '
                           'Description: %s;  Last updated: %s.',
-                          title, info.get('link', 'unavailable').strip(),
-                          desc, when)
+                          title, link, desc, when)
         irc.reply(utils.str.normalizeWhitespace(response))
     info = wrap(info, [first('url', 'feedName')])
 
